@@ -5,12 +5,12 @@ contr.FrF2 <- function (n)
     if (length(n) <= 1) {
         if (is.numeric(n) && length(n) == 1 && n > 1) 
             levels <- 1:n
-        else stop("invalid choice for n in contr.blocks")
+        else stop("invalid choice for n in contr.FrF2")
     }
     else levels <- n
     lenglev <- length(levels)
     if (!2^round(log2(lenglev))==lenglev) 
-        stop("contr.blocks requires that the number of levels is a power of 2.")
+        stop("contr.FrF2 requires that the number of levels is a power of 2.")
 
     ## definition of contrast matrix
        if (lenglev==2) destxt <- "matrix(c(-1,1),ncol=1)"
